6. Acknowledgments — ESIBD Explorer 0.6 documentation

# 6. Acknowledgments

The following list acknowledges classes, libraries, or other resources that were either used directly or adapted:

Author | Class, library, function, or resource
--- | ---
rauschi | LabVIEW based precursor ES-IBD control which established some of the core concepts.
Softmixt | Recursion function to display files and folders in QTreeWidget.
Owen | Arraylist implementation for NumPy.
jdreaver | Scientific QDoubleSpinBox.
JonB | Compact JComboBox for long items.
nlamprian | Custom LED indicator.
Axel-Erfurt | TextEdit with line numbers
Yusuke Kamiyamane | Fugue Icons